argv
Types
pub type Argv {
Argv(runtime: String, program: String, arguments: List(String))
}
Constructors
-
Argv(runtime: String, program: String, arguments: List(String))Arguments
- runtime
-
The path to the runtime executable. For example,
"/usr/bin/erl". - program
-
The path to the program being run. This may either be the entrypoint script for JavaScript, path of the escript for Erlang, or the path of the project if none of those could be determined.
- arguments
-
The command line arguments passed to the program.